@@ -7,10 +7,8 @@ from google.protobuf.json_format import MessageToDict
 from google.protobuf.message import Message
 from grpc import Channel, Server, StatusCode
 from delphai_utils.logging import logging
-from grpc_requests import Client
 from google.protobuf.descriptor_pb2 import MethodOptions
 from google.api.http_pb2 import HttpRule
-from grpc_requests.client import reset_cached_client
 from starlette.applications import Starlette
 from starlette.responses import JSONResponse
 from starlette.routing import Route
@@ -119,9 +117,8 @@ def get_http_handlers(descriptor: FileDescriptor, service_name: str, method: str
   return method_get_handler, request_handler
 
 
-def start_gateway(descriptor: FileDescriptor, loop: BaseEventLoop, port: int = 7070):
+async def start_gateway(descriptor: FileDescriptor, port: int = 7070):
   logging.info('starting gateway...')
-  reset_cached_client('localhost:8080')
   debug = 'DELPHAI_ENVIRONMENT' in os.environ and os.environ['DELPHAI_ENVIRONMENT'] == 'development'
   app = Starlette(debug=debug, exception_handlers={HTTPException: http_exception})
   app.add_middleware(AccessLogMiddleware)
@@ -153,6 +150,5 @@ def start_gateway(descriptor: FileDescriptor, loop: BaseEventLoop, port: int = 7
               http_path = getattr(http_rule, supported_method)
               if http_path != '':
                 app.add_route(http_path, route=request_handler, methods=[supported_method])
-  server = serve(app, config)
-  loop.create_task(server)
-  logging.info(f'started gateway on port {port}')
\ No newline at end of file
+  logging.info(f'started gateway on port {port}')
+  await serve(app, config)
\ No newline at end of file
