@@ -25,8 +25,8 @@ def create_grpc_server(descriptor: FileDescriptor):
   return server
 
 
-def start_server(server: Server, loop: BaseEventLoop):
+async def start_server(server: Server):
   logging.info('starting grpc server...')
-  loop.run_until_complete(server.start())
-  loop.create_task(server.wait_for_termination())
-  logging.info('started grpc server on port 8080')
\ No newline at end of file
+  await server.start()
+  logging.info('started grpc server on port 8080')
+  await server.wait_for_termination()
\ No newline at end of file
